#!/usr/bin/python3
# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
import subprocess
import argparse
import re
import socket

VIOS1_NETWORK_CMD = '/opt/ibm/pvm-install/bin/pvmconfigdata.py \
            -f /pvm-install.cfg -r -o d -s VIOS1NetworkSettings'

VIOS2_NETWORK_CMD = '/opt/ibm/pvm-install/bin/pvmconfigdata.py \
            -f /pvm-install.cfg -r -o d -s VIOS2NetworkSettings'
DEFAULT_GW_CMD = '/opt/ibm/pvm-install/bin/pvmconfigdata.py \
            -f /pvm-install.cfg -r -o d -s VIOSNIMServerConfig | \
            grep NOVALINK_PRIVATE_IP | cut -d \"=\" -f2 | tr -d \"\'\"'

DELETE_DEFAULT_CMD = 'chdev -l inet0 -a delroute='

CAT_DHCPCD_INI_CMD = 'cat /etc/dhcpcd.ini'

START_DHCP_CMD = "startsrc -s dhcpcd"

ENABLED = 'ENABLED'
DISABLED = 'DISABLED'


def invoke_operation(args):

    lpar_id = args.id
    interface = args.i

    if lpar_id == '2':
        viosNetwork = subprocess.getoutput(VIOS1_NETWORK_CMD)
    else:
        viosNetwork = subprocess.getoutput(VIOS2_NETWORK_CMD)

    dhcpip, ipaddress, gateway, netmask, dns1, dns2, dns3, \
        hostname, domain = '', '', '', '', '', '', '', '', ''

    for line in viosNetwork.splitlines():
        if 'DHCPIP' in line:
            dhcpip = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'IPADDRESS' in line:
            ipaddress = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'GATEWAY' in line:
            gateway = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'NETMASK' in line:
            netmask = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'DNS1' in line:
            dns1 = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'DNS2' in line:
            dns2 = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'DNS3' in line:
            dns3 = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'HOSTNAME' in line:
            hostname = re.findall(r"'(.*?)'", line, re.DOTALL)[0]
        elif 'DOMAIN' in line:
            domain = re.findall(r"'(.*?)'", line, re.DOTALL)[0]

    delete_default_route(lpar_id)

    fq_hostname = hostname + '.' + domain if domain != '' else hostname

    issue_tcpip_cmd(dhcpip, ipaddress, gateway, netmask, dns1,
                    fq_hostname, domain, interface, lpar_id)

    if dns2 != '':
        issue_tcpip_cmd(dhcpip, ipaddress, gateway, netmask, dns2,
                        fq_hostname, domain, interface, lpar_id)

    if dns3 != '':
        issue_tcpip_cmd(dhcpip, ipaddress, gateway, netmask, dns3,
                        fq_hostname, domain, interface, lpar_id)

    # Set the fully qualified hostname
    # Do this to persist it in inet0 device because the short hostname
    # has been previously set during NIM install of the VIOS, and was
    # bound to the private interface
    issue_set_hostname(lpar_id, fq_hostname)


def delete_default_route(lpar_id):

    defgw = subprocess.getoutput(DEFAULT_GW_CMD)
    del_gw = DELETE_DEFAULT_CMD + "'net,,0," + defgw + "'"
    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-r -c ' + '"' + del_gw + '"'
    subprocess.getoutput(viosvr_cmd)


def issue_dhcp_cmd(interface, lpar_id):

    interface_string = 'Interface ' + interface

    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-r -c ' + '"' + CAT_DHCPCD_INI_CMD + '"'

    subprocess.getoutput(CAT_DHCPCD_INI_CMD)

    # We will copy the novalinkdhcp over to vios as part of the install
    append_cmd = '/etc/novalinkdhcp ' + '"' + interface_string + '"'

    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-r -c ' + "'" + append_cmd + "'"

    # append the Interface en* string to dhcpcd.ini
    subprocess.getoutput(viosvr_cmd)

    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-r -c ' + '"' + START_DHCP_CMD + '"'

    # start the dhcpcd daemon
    subprocess.getoutput(viosvr_cmd)


def issue_set_hostname(lpar_id, hostname):

    chdev_cmd = 'chdev -dev inet0 -attr hostname='
    chdev_cmd = chdev_cmd + hostname
    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-c ' + '"' + chdev_cmd + '"'

    # start the dhcpcd daemon
    subprocess.getoutput(viosvr_cmd)


def issue_tcpip_cmd(dhcpip, ipaddress, gateway, netmask, dns,
                    hostname, domain, interface, lpar_id):

    is_ipv4 = False
    try:
        socket.inet_aton(ipaddress)
        is_ipv4 = True
    except socket.error:
        is_ipv4 = False

    mktcpip_cmd = 'mktcpip'

    if dhcpip == ENABLED:
        return issue_dhcp_cmd(interface, lpar_id)

    if is_ipv4:
        mktcpip_cmd = mktcpip_cmd + ' ' + '-inetaddr ' + ipaddress
        mktcpip_cmd = mktcpip_cmd + ' ' + '-gateway ' + gateway
        mktcpip_cmd = mktcpip_cmd + ' ' + '-netmask ' + netmask
        mktcpip_cmd = mktcpip_cmd + ' ' + '-hostname ' + hostname
        mktcpip_cmd = mktcpip_cmd + ' ' + '-interface ' + interface

        if dns != '':
            mktcpip_cmd += ' ' + '-nsrvaddr ' + dns
            mktcpip_cmd = mktcpip_cmd + ' ' + '-nsrvdomain ' + domain

        mktcpip_cmd = mktcpip_cmd + ' ' + '-start'
    else:
        mktcpip_cmd = mktcpip_cmd + ' ' + '-inetaddr ' + ipaddress
        mktcpip_cmd = mktcpip_cmd + ' ' + '-gateway ' + gateway
        mktcpip_cmd = mktcpip_cmd + ' ' + '-plen ' + '64'
        mktcpip_cmd = mktcpip_cmd + ' ' + '-hostname ' + hostname
        mktcpip_cmd = mktcpip_cmd + ' ' + '-interface ' + interface

    viosvr_cmd = 'viosvrcmd ' + '--id ' + lpar_id
    viosvr_cmd += ' ' + '-c ' + '"' + mktcpip_cmd + '"'

    subprocess.getoutput(viosvr_cmd)


def create_parser():
    parser = argparse.ArgumentParser(prog="cfgviosnetwork")

    # Target system name
    parser.add_argument("-id",
                        choices=["2", "3"],
                        required=True,
                        help="VIOS ID - 2 or 3")

    parser.add_argument("-i",
                        required=True,
                        help="Interface Name")

    return parser


def main():
    parser = create_parser()
    args = parser.parse_args()
    invoke_operation(args)

if __name__ == "__main__":
    main()
