# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2016
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.


from pvmconfigdata import PVMConfigData as pcd
from snack import Entry
from snack import Grid
from snack import GridForm
from snack import Label
from snack import SingleRadioButton
from snack import TextboxReflowed
from gettext import gettext as _
from wizpkg.wizardpanel import WizardPanel
from wizpkg.extendedwizardpanels import buildButtonBar


class ConfirmInstallPanel(WizardPanel):
    '''
    This class extends the base WizardPanel and uses
    one or more RadioButton as widget in its gridform.
             +-------------------------------+
             |     some title                |
             +-------------------------------+
             | Here are some instructions..  |
             |                               |
             | [ ] Some text                 |
             | [ ] Some other text           |
             | ...                           |
             |                               |
             | <back>   <next>   <cancel>    |
             +-------------------------------+
    '''
    INSTALL_DEFAULT = 'INSTALL_DEFAULT'
    INSTALL_OTHER = 'INSTALL_OTHER'
    INSTALL_RHEL = 'INSTALL_RHEL'
    NAME = 'CONFIRM_INSTALL'

    def __init__(self, screen, osinfo, cfgparser, greenfld):
        '''
        Init method
        :param screen: SnackScreen instance
        :param osinfo: String containing default OS information
        :param cfgparser: Config file parser
        :param greenfld: Indicates if this install is greenfield or not
        '''
        paneltitle = _("Confirm Installation")
        msg = _("Select one of the installation options.")
        ks_val = cfgparser.get_attribute(pcd.PVM_CONFIG_SECTION,
                                         pcd.KS_FILE)
        inst_src_val = cfgparser.get_attribute(pcd.PVM_CONFIG_SECTION,
                                               pcd.INSTALLATION_SOURCE)
        other_os_val = cfgparser.get_attribute_boolean(
            pcd.PVM_CONFIG_SECTION, pcd.INSTALL_OTHER_OS, False)

        gf = GridForm(screen, paneltitle, 1, 3)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)

        gf_install_msg = _("Install VIOS(s) and NovaLink with Ubuntu "
                           "- Automatic")
        ng_install_msg = _("Install NovaLink with Ubuntu - Automatic")
        gf_auto_msg = _("Install VIOS(s) and NovaLink with RHEL - Automatic")
        ng_auto_msg = _("Install NovaLink with RHEL - Automatic")
        gf_manual_msg = _("Install VIOS(s) and NovaLink with other OS "
                          "- Manual")
        ng_manual_msg = _("Install NovaLink with other OS - Manual")
        installmsg = _(osinfo)
        gf_manualosmsg = _("This will reboot to SMS after the VIOS(s) are "
                           "installed to allow for manual install of the OS "
                           "and NovaLink.")
        ng_manualosmsg = _("This will reboot to SMS for manual install of "
                           "the OS and NovaLink.")
        install_button_msg = gf_install_msg if greenfld else ng_install_msg
        auto_button_msg = gf_auto_msg if greenfld else ng_auto_msg
        manual_button_msg = gf_manual_msg if greenfld else ng_manual_msg
        manual_os_msg = gf_manualosmsg if greenfld else ng_manualosmsg

        self.installrb = SingleRadioButton(install_button_msg, None,
                                           0 if other_os_val else 1)
        self.rhelosrb = SingleRadioButton(auto_button_msg,
                                          self.installrb,
                                          1 if other_os_val else 0)
        self.otherosrb = SingleRadioButton(manual_button_msg,
                                           self.rhelosrb, 0)
        self.ks_entry = Entry(40, text=ks_val if ks_val else "http://")
        self.inst_src_entry = Entry(
            40, text=inst_src_val if inst_src_val else "http://")
        g = Grid(1, 6)
        osg = Grid(2, 2)
        g.setField(self.installrb, 0, 0, padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, installmsg), 0, 1,
                   padding=(4, 0, 1, 1), anchorLeft=1)
        g.setField(self.rhelosrb, 0, 2, padding=(0, 0, 1, 0), anchorLeft=1)
        osg.setField(Label(_("Kickstart File ")), 0, 0,
                     padding=(6, 0, 0, 0), anchorLeft=1)
        osg.setField(self.ks_entry, 1, 0, anchorLeft=1)
        osg.setField(Label(_("Installation Source ")), 0, 1,
                     padding=(6, 0, 1, 1), anchorLeft=1)
        osg.setField(self.inst_src_entry, 1, 1, anchorLeft=1)
        g.setField(osg, 0, 3, padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(self.otherosrb, 0, 4, padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, manual_os_msg), 0, 5,
                   padding=(4, 0, 1, 1), anchorLeft=1)
        gf.add(tb, 0, 0, padding=(0, 0, 1, 1), anchorLeft=1)
        gf.add(g, 0, 1, growy=1, anchorTop=0)
        bb = buildButtonBar(screen, WizardPanel.LAST)
        gf.add(bb, 0, 2, padding=(0, 1, 0, 0), growx=1)
        self.buttonBar = bb
        super(ConfirmInstallPanel, self).__init__(
            screen=screen, name=ConfirmInstallPanel.NAME,
            gridform=gf, panelaction=None)

    def getValues(self):
        '''
        Obtain values selected
        :return: INSTALL_DEFAULT, INSTALL_RHEL or INSTALL_OTHER
        '''
        if self.installrb.selected():
            return ConfirmInstallPanel.INSTALL_DEFAULT
        elif self.rhelosrb.selected():
            return ConfirmInstallPanel.INSTALL_RHEL
        else:
            return ConfirmInstallPanel.INSTALL_OTHER
