# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.


class PhysicalAdapter(object):
    '''
    This class represents the physical adapter object that will
    be used to persist information entered on the physical adapter panel
    '''

    def __init__(self, owner_names, adapterdict, io_assign_dict, start, end):
        '''
        param: owner_names is an array list of names of active owners of
               physical adapters, e.g. ["VIOS1", "SDN1"]
        param: adapterdict is a dictionary holding all the physical adapters,
               with each adapter being represented as a <drc: description>
               pair.
        param: io_assign_dict is a two level dictionary that holds a
               partition of all the physical adapters among active adapter
               owners. This is an example:
               {'VIOS1': {'C2-P1': 'new adapter',
                          'C1-P1': 'old adapter'},
                'SDN1': {'C3-P1', '100 G',
                         'C4-P1', 'sriov'}}
        param: start is the starting index of the physical adapter list
        param: end is the last index being displayed
        '''
        self.owner_names = owner_names.copy()
        self._adapterdict = adapterdict
        self._io_assign_dict = io_assign_dict.copy()
        self._start = start
        self._end = end

    @property
    def adapterdict(self):
        return self._adapterdict

    @property
    def io_assign_dict(self):
        return self._io_assign_dict

    @property
    def start(self):
        return self._start

    @property
    def end(self):
        return self._end

    @start.setter
    def start(self, start):
        self._start = start

    @end.setter
    def end(self, end):
        self._end = end

    def update_assignment(self, new_assign_dict):
        '''
        Update the internal dictionary, _io_assign_dict, according to the
        new_assign_dict dictionary which is contructed from the fresh read
        out of the radio buttons of the physical adapter selection wizard
        screen that is defined in iopanel.py
        '''
        adapter_to_owner_dict = {}
        for new_owner, new_iolist in new_assign_dict.items():
            for drc, desc in new_iolist.items():
                adapter_to_owner_dict.update({(drc, desc): new_owner})

        for (drc, desc), new_owner in adapter_to_owner_dict.items():
            for old_owner, old_iolist in self._io_assign_dict.items():
                if new_owner == old_owner and drc not in old_iolist:
                    old_iolist.update({drc: desc})
                if new_owner != old_owner and drc in old_iolist:
                    del old_iolist[drc]
