# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
import ipaddress


class BadNetworkSettingsException(Exception):
    def __init__(self, msg):
        self.msg = msg

    def __str__(self):
        return self.msg


class Network(object):
    '''
    This class represents the netwrok object that will
    be used to persist information entered on the user panel
    '''

    IPV4 = '4'
    IPV6 = '6'

    def __init__(self, hostname, domainname, ipaddr, netmask, gateway,
                 dhcpproto, dns1, dns2, dns3):
        self._dhcpproto = dhcpproto
        self._hostname = hostname
        self._domainname = domainname
        self._ipaddr = ipaddr
        self._netmask = netmask
        self._gateway = gateway
        self._dns1 = dns1
        self._dns2 = dns2
        self._dns3 = dns3

    @property
    def dhcp_protocol(self):
        return self._dhcpproto

    @property
    def hostname(self):
        return self._hostname

    @property
    def domainname(self):
        return self._domainname

    @property
    def ipaddress(self):
        return self._ipaddr

    @property
    def networkmask(self):
        return self._netmask

    @property
    def gateway(self):
        return self._gateway

    @property
    def dns1(self):
        return self._dns1

    @property
    def dns2(self):
        return self._dns2

    @property
    def dns3(self):
        return self._dns3

    @dhcp_protocol.setter
    def dhcp_protocol(self, dhcpproto):
        self._dhcpproto = dhcpproto

    @hostname.setter
    def hostname(self, hostname):
        self._hostname = hostname

    @domainname.setter
    def domainname(self, domainname):
        self._domainname = domainname

    @ipaddress.setter
    def ipaddress(self, ipaddr):
        self._ipaddr = ipaddr

    @networkmask.setter
    def networkmask(self, netmask):
        self._netmask = netmask

    @gateway.setter
    def gateway(self, gateway):
        self._gateway = gateway

    @dns1.setter
    def dns1(self, dns1):
        self._dns1 = dns1

    @dns2.setter
    def dns2(self, dns2):
        self._dns2 = dns2

    @dns3.setter
    def dns3(self, dns3):
        self._dns3 = dns3

    @staticmethod
    def validate(networkobj):
        exmsg = ""
        if not networkobj.hostname:
            exmsg = exmsg + "\n" + _("hostname cannot be empty.")
        if not networkobj.dhcp_protocol:
            if not networkobj.ipaddress:
                exmsg = exmsg + "\n" + _("ip address cannot be empty.")
            else:
                try:
                    ipaddress.IPv4Network(networkobj.ipaddress)
                except ValueError:
                    try:
                        ipaddress.IPv6Network(networkobj.ipaddress)
                    except ValueError:
                        exmsg = exmsg + ("\n" + _("Invalid IP address: ") +
                                         networkobj.ipaddress)
            if not networkobj.gateway:
                exmsg = exmsg + "\n" + _("gateway address cannot be empty.")
            else:
                try:
                    ipaddress.IPv4Network(networkobj.gateway)
                except ValueError:
                    try:
                        ipaddress.IPv6Network(networkobj.gateway)
                    except ValueError:
                        exmsg = exmsg + ("\n" + _("Invalid IP address "
                                                  "for gateway: ") +
                                         networkobj.gateway)
            if not networkobj.networkmask:
                exmsg = exmsg + "\n" + _("network mask cannot be empty.")
            else:
                try:
                    ipaddress.IPv4Network(networkobj.networkmask)
                except ValueError:
                    try:
                        ipaddress.IPv6Network(networkobj.networkmask)
                    except ValueError:
                        exmsg = exmsg + ("\n" + _("Invalid IP address "
                                                  "for network mask: ") +
                                         networkobj.networkmask)

        if networkobj.dns1:
            try:
                ipaddress.IPv4Network(networkobj.dns1)
            except ValueError:
                try:
                    ipaddress.IPv6Network(networkobj.dns1)
                except ValueError:
                    exmsg = exmsg + ("\n" + _("Invalid IP address "
                                              "for DNS1: ") + networkobj.dns1)
        if networkobj.dns2:
            try:
                ipaddress.IPv4Network(networkobj.dns2)
            except ValueError:
                try:
                    ipaddress.IPv6Network(networkobj.dns2)
                except ValueError:
                    exmsg = exmsg + ("\n" + _("Invalid IP address "
                                              "for DNS2: ") + networkobj.dns2)
        if networkobj.dns3:
            try:
                ipaddress.IPv4Network(networkobj.dns3)
            except ValueError:
                try:
                    ipaddress.IPv6Network(networkobj.dns3)
                except ValueError:
                    exmsg = exmsg + ("\n" + _("Invalid IP address "
                                              "for DNS3: ") + networkobj.dns3)
        if exmsg:
            raise BadNetworkSettingsException(exmsg)
        else:
            return 0
