# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
from wizpkg.extendedwizardpanels import RadioButtonWizardPanel
from wizpkg.extendedwizardpanels import RadioButton2ColumnWizardPanel
from wizpkg.extendedwizardpanels import MissingTupleException
from wizpkg.wizardpanel import WizardPanel
from pvmconfigdata import PVMConfigData as pcd


def _show_vios_link_aggregation(screen, cfgparser):
    panelName = _("Virtual Network Bridge")
    panelTitle = _("Virtual Network Bridge")
    val = cfgparser.get_attribute(pcd.VIOS1_NETWORK_BRIDGE,
                                  pcd.LINK_AGGREGATION_TYPE)
    panelMessage = _("Choose the appropriate link aggregation type for "
                     "the VIOS (SEA) network bridge")
    tuplemsg1 = _("EtherChannel (standard)")
    tuplemsg2 = _("EtherChannel (round robin)")
    tuplemsg3 = _("8023.ad Link Aggregation")
    panelButtonTuple = [(tuplemsg1, 0, 1 if val == 'standard' else 0),
                        (tuplemsg2, 1, 1 if val == 'round_robin' else 0),
                        (tuplemsg3, 2, 1 if val == '8023ad' else 0)]
    try:
        mainPanel = RadioButtonWizardPanel(screen, panelName,
                                           panelTitle, panelMessage,
                                           panelButtonTuple,
                                           WizardPanel.MIDDLE,
                                           panelaction=None)
        mainPanel.run()
    except MissingTupleException:
        WizardPanel.showError(screen, _("An error has occurred."))
    nextPanel = mainPanel.next()
    if nextPanel == WizardPanel.NEXT:
        selectedValue = mainPanel.getValues()
        if selectedValue == 0:
            cfgparser.set_attribute(pcd.VIOS1_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE, 'standard')
            cfgparser.set_attribute(pcd.VIOS2_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE, 'standard')
        elif selectedValue == 1:
            cfgparser.set_attribute(pcd.VIOS1_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE,
                                    'round_robin')
            cfgparser.set_attribute(pcd.VIOS2_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE,
                                    'round_robin')
        elif selectedValue == 2:
            cfgparser.set_attribute(pcd.VIOS1_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE, '8023ad')
            cfgparser.set_attribute(pcd.VIOS2_NETWORK_BRIDGE,
                                    pcd.LINK_AGGREGATION_TYPE, '8023ad')
    else:
        return nextPanel

    return WizardPanel.NEXT


def _set_sdn_cfg_attrs(cfgparser, mainPanel):
    selectedValues = mainPanel.getValues()
    link_aggr_types = ['Server Load Balance', 'Active/Backup', 'LACP Active',
                       'LACP Passive']
    failure_detect_algs = ['Miimon', 'Carrier']
    link_aggr = link_aggr_types[selectedValues[0]]
    failure_detection = failure_detect_algs[selectedValues[1]]
    cfgparser.set_attribute(pcd.SDN1_NETWORK_BRIDGE,
                            pcd.LINK_AGGREGATION_TYPE,
                            link_aggr)
    cfgparser.set_attribute(pcd.SDN2_NETWORK_BRIDGE,
                            pcd.LINK_AGGREGATION_TYPE,
                            link_aggr)
    cfgparser.set_attribute(pcd.SDN1_NETWORK_BRIDGE,
                            pcd.FAILURE_DETECTION_ALGORITHM,
                            failure_detection)
    cfgparser.set_attribute(pcd.SDN2_NETWORK_BRIDGE,
                            pcd.FAILURE_DETECTION_ALGORITHM,
                            failure_detection)


def _show_sdn_link_aggregation(screen, cfgparser):
    panelName = _("Virtual Network Bridge")
    panelTitle = _("Virtual Network Bridge")
    default_val = cfgparser.get_attribute(pcd.SDN1_NETWORK_BRIDGE,
                                          pcd.LINK_AGGREGATION_TYPE)
    panelMessage = _("Choose appropriate link aggregation parameters "
                     "for the SDN bridge")
    rblist1_heading = _("Bonding Type")
    panelButtonTuple1 = [(_("Server Load Balance"), 0,
                          1 if default_val == 'Server Load Balance' else 0),
                         (_("Active/Backup"), 1,
                          1 if default_val == 'Active/Backup' else 0),
                         (_("LACP Active"), 2,
                          1 if default_val == 'LACP Active' else 0),
                         (_("LACP Passive"), 3,
                          1 if default_val == 'LACP Passive' else 0)]

    rblist2_heading = _("Failure Detection Algorithm")
    rblist2_entry1 = _("Miimon (Media Ind Intf monitor)")
    rblist2_entry2 = _("Carrier")
    default_val = cfgparser.get_attribute(pcd.SDN1_NETWORK_BRIDGE,
                                          pcd.FAILURE_DETECTION_ALGORITHM)
    panelButtonTuple2 = [(rblist2_entry1, 0,
                          1 if default_val == 'Miimon' else 0),
                         (rblist2_entry2, 1,
                          1 if default_val == 'Carrier' else 0)]
    try:
        panelmsgs = [panelName, panelTitle, panelMessage,
                     rblist1_heading, rblist2_heading]
        mainPanel = RadioButton2ColumnWizardPanel(screen, panelmsgs,
                                                  panelButtonTuple1,
                                                  panelButtonTuple2,
                                                  WizardPanel.MIDDLE,
                                                  panelaction=None)
        mainPanel.run()
    except MissingTupleException:
        WizardPanel.showError(screen, _("An error has occurred."))
    nextPanel = mainPanel.next()
    if nextPanel == WizardPanel.NEXT:
        _set_sdn_cfg_attrs(cfgparser, mainPanel)

    return nextPanel


def show_link_aggregation(screen, cfgparser, bridge_name):
    '''
    Displays the panel to ask for link aggregation type
    '''
    nextpanel = WizardPanel.NEXT
    if ("VIOS" in bridge_name):
        nextpanel = _show_vios_link_aggregation(screen, cfgparser)
    if ("SDN" in bridge_name):
        nextpanel = _show_sdn_link_aggregation(screen, cfgparser)

    return nextpanel
