# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _


class BadMemorySettingsException(Exception):
    def __init__(self, msg):
        self.msg = msg

    def __str__(self):
        return self.msg


class MemInfo(object):
    '''
    This class holds memory info for a partition
    '''

    def __init__(self, minmemory, maxmemory, desiredmemory, lmbsize):
        self._minmemory = minmemory
        self._maxmemory = maxmemory
        self._desiredmemory = desiredmemory
        self._lmbsize = lmbsize

    @property
    def minmemory(self):
        return self._minmemory

    @minmemory.setter
    def minmemory(self, minmemory):
        self._minmemory = minmemory

    @property
    def maxmemory(self):
        return self._maxmemory

    @maxmemory.setter
    def maxmemory(self, maxmemory):
        self._maxmemory = maxmemory

    @property
    def desiredmemory(self):
        return self._desiredmemory

    @desiredmemory.setter
    def desiredmemory(self, desiredmemory):
        self._desiredmemory = desiredmemory

    @property
    def lmbsize(self):
        return self._lmbsize

    def validate(self):
        desiredmem = 0
        minmem = 0
        maxmem = 0
        try:
            minmem = float(self._minmemory)
        except ValueError:
            raise BadMemorySettingsException(_("Bad value "
                                               "for minimum memory"))
        try:
            maxmem = float(self._maxmemory)
        except ValueError:
            raise BadMemorySettingsException(_("Bad value "
                                               "for maximum memory"))
        try:
            desiredmem = float(self._desiredmemory)
        except ValueError:
            raise BadMemorySettingsException(_("Bad value "
                                               "for desired memory"))

        if not (desiredmem >= minmem and desiredmem <= maxmem):
            raise BadMemorySettingsException(_("Desired memory value is not "
                                               "in the range of %s "
                                               "and %s" %
                                               (self._minmemory,
                                                self._maxmemory)))
        # Desired memory must be multiple of lmbsize
        memval = int(desiredmem * 1024)
        memregion = int(self._lmbsize)

        if ((memval % memregion) != 0):
            raise BadMemorySettingsException(_("Desired memory value is not "
                                               "a multiple of %s" %
                                               self._lmbsize))
        memval = int(minmem * 1024)
        if ((memval % memregion) != 0):
            raise BadMemorySettingsException(_("Minimum memory value is not "
                                               "a multiple of %s" %
                                               self._lmbsize))
        memval = int(maxmem * 1024)
        if ((memval % memregion) != 0):
            raise BadMemorySettingsException(_("Maximum memory value is not "
                                               "a multiple of %s" %
                                               self._lmbsize))
