# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _


class BadVirtProcSettingsException(Exception):
    def __init__(self, msg):
        self.msg = msg

    def __str__(self):
        return self.msg


class VirtProcInfo(object):
    '''
    This class holds virtual processor information
    For a partition
    '''

    def __init__(self, minvirtproc, maxvirtproc, desiredvirtproc):
        self._minvirtproc = minvirtproc
        self._maxvirtproc = maxvirtproc
        self._desiredvirtproc = desiredvirtproc

    @property
    def minvirtproc(self):
        return self._minvirtproc

    @minvirtproc.setter
    def minvirtproc(self, minvirtproc):
        self._minvirtproc = minvirtproc

    @property
    def maxvirtproc(self):
        return self._maxvirtproc

    @maxvirtproc.setter
    def maxvirtproc(self, maxvirtproc):
        self._maxvirtproc = maxvirtproc

    @property
    def desiredvirtproc(self):
        return self._desiredvirtproc

    @desiredvirtproc.setter
    def desiredvirtproc(self, desiredvirtproc):
        self._desiredvirtproc = desiredvirtproc

    def validate(self):
        procrequested = 0
        minproc = 0
        maxproc = 0
        try:
            minproc = int(self._minvirtproc)
        except ValueError:
            raise BadVirtProcSettingsException(_("Bad integer value "
                                                 "for minimum virtual proc"))
        try:
            maxproc = int(self._maxvirtproc)
        except ValueError:
            raise BadVirtProcSettingsException(_("Bad integer value "
                                                 "for maximum virtual proc"))
        try:
            procrequested = int(self._desiredvirtproc)
        except ValueError:
            raise BadVirtProcSettingsException(_("Bad integer value "
                                                 "for desired virtual proc"))

        if not (procrequested >= minproc and procrequested <= maxproc):
            raise BadVirtProcSettingsException(_("Desired virtual proc value "
                                                 "not in the range of %s "
                                                 "and %s" %
                                                 (minproc, maxproc)))
