# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

import datetime
import pytz
from snack import Grid
from snack import GridForm
from snack import Listbox
from snack import TextboxReflowed
from wizpkg.wizardpanel import WizardPanel


class TimeZoneSelectionPanel(WizardPanel):
    '''
    This class provides a panel with world wide timezone
    information for user to select. Only 1 selection allowed.
             +---------------------------------------------------+
             |     some title                                    |
             +---------------------------------------------------+
             | Here are some instructions..                      |
             |                                                   |
             | (*) America/New_York                              |
             | ( ) America/Chicago                               |
             |  .............................                    |
             |                                                   |
             +---------------------------------------------------+
    '''

    def __init__(self, screen, name, paneltitle, msg, timezonelist,
                 index, panelaction):

        gf = GridForm(screen, paneltitle, 1, 3)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)
        self.tzlb = Listbox(10, scroll=1, returnExit=1)
        for val in timezonelist:
            try:
                offset = pytz.timezone(val).localize(datetime.datetime.now()
                                                     ).strftime('%z')
                self.tzlb.append(val+" "+offset, val)
            except pytz.UnknownTimeZoneError:
                # Ignore any unknown time
                pass
        g = Grid(1, 1)
        g.setField(self.tzlb, 0, 0, padding=(0, 0, 1, 1),
                   anchorLeft=1, anchorTop=1)
        gf.add(tb, 0, 0, padding=(0, 0, 0, 1), anchorTop=0)
        gf.add(g, 0, 1, growy=1, padding=(0, 0, 1, 0), anchorLeft=1)
        self.buttonBar = None
        super(TimeZoneSelectionPanel, self).__init__(screen=screen,
                                                     name=name, gridform=gf,
                                                     panelaction=panelaction)

    def getValues(self):
        '''
        Obtain list of values
        '''
        return self.tzlb.current()
