#!/usr/bin/python3
# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

import codecs
import getopt
import locale
import logging
import six
import sys
import gettext
from gettext import gettext as _
from installPVMPartitionWizard import run_pvm_install_wizard
from installPVMPartitionWizard import show_cancel
from recovery.recoverymain import run_recovery_wizard
from snack import SnackScreen
from snack import ButtonBar
from welcome import WelcomeWizardPanel
from welcome import DefaultOrCustomWizardPanel
from wizpkg.extendedwizardpanels import TextMessageWizardPanel
from wizpkg.wizardpanel import WizardPanel
from pvmconfigdata import PVMConfigData as pcd


def printusage():
    six.print_(_("Usage: %s [ -f file ] [ -d ] [-g] [ -h | --help ]")
               % sys.argv[0],
               file=sys.stderr)
    six.print_(_("     -f    : Configuration file"), file=sys.stderr)
    six.print_(_("     -d    : Enable debug"), file=sys.stderr)
    six.print_(_("     -g    : Greenfield mode"), file=sys.stderr)
    six.print_(_("     -m    : Install Mode"), file=sys.stderr)
    six.print_(_("-h , --help: Prints this help message"), file=sys.stderr)
    sys.exit(2)


def run_recover_pvm_wizard(screen_p):
    '''
    Perform recovery task
    '''
    retVal = run_recovery_wizard(screen_p)

    return retVal

if __name__ == "__main__":

    # This is the main entry point into the installer wizard
    # It is responsible for presenting a few panels to the user
    # in order to ask basic questions and save certain needed
    # settings to be used later on for the main wizard.

    gettext.textdomain('pvm-install')
    locale.setlocale(locale.LC_ALL, None)

    cfgfile = ""
    debug = False
    # greenfield mode will allow creation and install of VIOS
    greenfield = False
    # showall panel or skip and use defaults as much as possible
    showall = False
    ACCEPT = 1
    DONOTACCEPT = 2
    licenseAccepted = False
    installmode = ""
    show_vios = True

    try:
        options, remainder = getopt.getopt(sys.argv[1:], 'f:m:dgh', ['help'])
    except getopt.GetoptError as e:
        print(str(e))
        printusage()

    for opt, arg in options:
        if opt in ('-h', '--help'):
            printusage()
        elif opt in ('-f'):
            cfgfile = arg
        elif opt in ('-d'):
            debug = True
        elif opt in ('-g'):
            greenfield = True
        elif opt in ('-m'):
            installmode = arg

# Setup log facility

    logger = logging.getLogger('pvmwizard')
    hdlr = logging.FileHandler('/var/log/pvmwizard.log')
    formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
    logger.addHandler(hdlr)
    logger.setLevel(logging.INFO)

    # decide whether vios related info will be shown
    if not greenfield or installmode == pcd.SDE:
        show_vios = False

    screen = SnackScreen()
    licbb = ButtonBar(screen, ((_("I Do Not Accept"), DONOTACCEPT),
                               (_("I Accept"), ACCEPT)), compact=1)
    initp_msg = _("Welcome to the PowerVM NovaLink Install wizard.")

    # The real text from license agreement needs to be obtained from a file
    # Once we get to the point of enabling NLS, then the locale setting will
    # be used to pull the proper translated license file.
    licensePref = "/usr/share/pvm/license/LA_"
    licenseFile = ""
    licenseFileDef = "/usr/share/pvm/license/LA_en"
    try:
        locale.setlocale(locale.LC_ALL, "")
        lang = locale.getlocale()[0]
        if not lang:
            # for locale setting of C or POSIX default to en
            # since lang value is of type None. Not handling
            # it here will cause the next if statement to fail
            lang = "en"
        # license file to zh_TW is LA_zh_TW
        if "TW" not in lang:
            lang = lang[:2]
        licenseFile = licensePref + lang
    except locale.Error:
        licenseFile = licenseFileDef
    fileObj = None
    try:
        fileObj = codecs.open(licenseFile, "r", "utf-8")
    except IOError:
        fileObj = codecs.open(licenseFileDef, "r", "utf-8")
    licensep_msg = fileObj.read()
    # TODO:
    # - Button to show non-ibm-license file
    defaultcustom_msg = _("Additional parameters than those found in this "
                          "wizard can be viewed and customized by selecting "
                          "'Edit Settings' button on the last panel.")
    while True:
        initp = WelcomeWizardPanel(screen, "INITIAL_PANEL",
                                   _("Welcome"), initp_msg, show_vios,
                                   WizardPanel.FIRST, panelaction=None)
        licensep = TextMessageWizardPanel(screen, "LICENSE_PANEL",
                                          _("License Agreement"), licensep_msg,
                                          licbb, WizardPanel.FIRST,
                                          panelaction=None)
        status = WizardPanel.RUNNING
        initp.run()
        nextPanel = initp.next()
        selVal = initp.getValues()
        if nextPanel != WizardPanel.CANCEL:
            if selVal == WelcomeWizardPanel.INSTALL:
                # Only show custom or default selection in case
                # of greenfield. In non greenfield there is no difference
                # between default and custom.
                if greenfield:
                    custdefp = DefaultOrCustomWizardPanel(screen,
                                                          "DEFAULT_CUSTOM",
                                                          _("Welcome"),
                                                          defaultcustom_msg,
                                                          WizardPanel.MIDDLE,
                                                          panelaction=None)
                    custdefp.run()
                    nextPanel = custdefp.next()
                    psel = custdefp.getValues()
                    if nextPanel == WizardPanel.NEXT:
                        if psel == DefaultOrCustomWizardPanel.CUSTOM:
                            showall = True
                    else:
                        if nextPanel == WizardPanel.CANCEL:
                            status = show_cancel(screen)
                        continue
                # Now proceed to ask license panel if needed
                # and start the remaining wizard
                if not licenseAccepted:
                    licensep.run()
                    result = licensep.next()
                    if result == ACCEPT:
                        licenseAccepted = True
                    else:
                        continue
                # Run the install wizard
                status = run_pvm_install_wizard(screen, cfgfile, showall,
                                                greenfield, show_vios)
            elif selVal == WelcomeWizardPanel.RECOVER:
                status = run_recovery_wizard(screen)
        # Cancel
        else:
            status = show_cancel(screen)

        logger.info("Status = %d\n", status)
        if status in (WizardPanel.EXIT, WizardPanel.FINISH):
            break

    screen.finish()
