# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

import ast
from snack import Grid
from snack import GridForm
from snack import SingleRadioButton
from snack import TextboxReflowed
from gettext import gettext as _
from wizpkg.wizardpanel import WizardPanel


class DoSDNWizardPanel(WizardPanel):
    '''
    This class extends the base WizardPanel to facilitate the installation
    operator to decide whether to enable SDN (Software Defined Networking).

    -----------------------------------------------------------------------
    |                   Software Defined Networking (SDN)                 |
    -----------------------------------------------------------------------
    |                                                                     |
    |   Enable Software Defined Networking (SDN).                         |
    |                                                                     |
    | (*) Choose to enable SDN.                                           |
    |     This will install the software and configure the system to be   |
    |     ready for SDN. The NovaLink partition will host the physical    |
    |     Ethernet adapters needed for SDN.                               |
    |                                                                     |
    | ( ) Choose not to enable SDN.                                       |
    |     This will not install the software or configure the system to be|
    |     ready for SDN. You can continue to use the Shared Ethernet      |
    |     Adapter infrastructure instead.                                 |
    |                                                                     |
    |                                                                     |
    |         <Back>                <Next>                <Cancel>        |
    |                                                                     |
    -----------------------------------------------------------------------
    '''
    DOSDN = 'DOSDN'
    NOSDN = 'NOSDN'

    def __init__(self, screen, name, paneltitle, msg,
                 doSdn, bb, panelaction):
        '''
        Init method
        :param screen: SnackScreen instance
        :param name: Name of the panel
        :param paneltitle: Panel title displayed to user
        :param msg: Message displayed to user as instructions
        :param doSdn: To enable SDN or not
        :param bb: Button bar
        :param panelaction: Function to be called when user transitions out
        '''
        gf = GridForm(screen, paneltitle, 1, 3)
        tb = TextboxReflowed(WizardPanel.WIDTH, msg)

        do_sdn = True if doSdn == '' else ast.literal_eval(str(doSdn))
        doSdn_button_msg = _("Choose to enable SDN.")
        doSdnmsg = _("This will install the software and configure the "
                     "system to be ready for SDN. The NovaLink partition will "
                     "host the physical Ethernet adapters needed for SDN.")
        noSdn_button_msg = _("Choose not to enable SDN.")
        noSdnmsg = _("This will not install the software or configure the "
                     "system to be ready for SDN. You can continue to use the"
                     " Shared Ethernet Adapter infrastructure instead.")
        self.doSdnrb = SingleRadioButton(doSdn_button_msg, 0,
                                         1 if do_sdn else 0)
        self.noSdnrb = SingleRadioButton(noSdn_button_msg,
                                         self.doSdnrb,
                                         0 if do_sdn else 1)
        g = Grid(1, 4)
        g.setField(self.doSdnrb, 0, 0,
                   padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, doSdnmsg), 0, 1,
                   padding=(4, 0, 0, 1), anchorLeft=1)
        g.setField(self.noSdnrb, 0, 2,
                   padding=(0, 0, 1, 0), anchorLeft=1)
        g.setField(TextboxReflowed(WizardPanel.WIDTH, noSdnmsg), 0, 3,
                   padding=(4, 0, 0, 1), anchorLeft=1)

        gf.add(tb, 0, 0, padding=(0, 0, 0, 1), anchorTop=0)
        gf.add(g, 0, 1, growy=1, anchorTop=0)
        self.buttonBar = bb
        gf.add(bb, 0, 2, padding=(0, 1, 0, 0), growx=1)
        super(DoSDNWizardPanel, self).__init__(screen=screen,
                                               name=name, gridform=gf,
                                               panelaction=panelaction)

    def getValues(self):
        '''
        Obtain values selected
        '''
        if self.doSdnrb.selected():
            return DoSDNWizardPanel.DOSDN
        elif self.noSdnrb.selected():
            return DoSDNWizardPanel.NOSDN
