# IBM CONFIDENTIAL
#
# OBJECT CODE ONLY SOURCE MATERIALS
#
# COPYRIGHT International Business Machines Corp. 2015
# All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

from gettext import gettext as _
import re


class BadUserNameException(Exception):

    def __init__(self):
        self.msg = _("Invalid character in user name")

    def __str__(self):
        return self.msg


class User(object):
    '''
    This class represents the user object that will
    be used to persist information entered on the user panel
    '''

    # A basic regular expression used to validate user name
    # This rule is the default rule in useradd.conf. If user
    # choose to define their own rules later (like using PAM)
    # then they can modify manually later.
    # To do: Add min and max name length checking?

    NAME_REGEX = "^[a-zA-Z0-9_.-]+$"

    def __init__(self, name, password1, password2):
        self._username = name
        self._passwd1 = password1
        self._passwd2 = password2

    @property
    def username(self):
        return self._username

    @username.setter
    def username(self, name):
        self._username = name

    @property
    def passwd1(self):
        return self._passwd1

    @property
    def passwd2(self):
        return self._passwd2

    @passwd1.setter
    def passwd1(self, passwd):
        self._passwd1 = passwd

    @passwd2.setter
    def passwd2(self, passwd):
        self._passwd2 = passwd

    @staticmethod
    def validateusername(username):
        if re.match(User.NAME_REGEX, username) is not None:
            return 0
        else:
            raise BadUserNameException
